@@ -3,7 +3,7 @@ package Captive::Portal;
 use strict;
 use warnings;
 
-our $VERSION = '2.10';
+our $VERSION = '2.11';
 
 =head1 NAME
 
@@ -87,157 +87,6 @@ The configuration file is searched in the following default places:
     $Bin/../etc/local/config.pl ||
     $Bin/../etc/config.pl
 
-=head1 CONFIGURATION PARAMETERS
-
-The configuration syntax is perl.
-
-
-=head2 PRESET GLOBAL PACKAGE VARIABLES, CHANGES POSSIBLE
-
-The following variables can be used for interpolation in config values.
-
- $APP_NAME = 'capo'
-
- $APP_DIR = "$Bin/../"
-
-=head2 PRESET DEFAULTS, CHANGES POSSIBLE
-
-=over 4
-
-=item DOCUMENT_ROOT => "$APP_DIR/static"
-
-Basedir for static content like images, css or error pages.
-
-=item TEMPLATE_INCLUDE_PATH => "$APP_DIR/templates/local/:$APP_DIR/templates/orig"
-
-Directories to search for templates.
-
-=item RUN_USER => 'wwwrun'
-
-Drop privileges to RUN_USER.
-
-=item RUN_GROUP => 'www',
-
-Drop privileges to RUN_GROUP.
-
-=item SESSIONS_DIR => "/var/cache/$APP_NAME"
-
-Where to store the session files. This directory must exist und must be readable/writeable by RUN_USER.
-
-=item SECURE_COOKIE => ON
-
-If this attribute is set, the cookie will only be sent to your script if the CGI request is occurring on a secure channel, such as SSL.
-
-=item SESSION_MAX => 48 * 3600    # 2d
-
-Max session time until a forced disconnect.
-
-=item IDLE_TIME => 60 * 10      # 10 min
-
-How long to wait for activity from ip/mac until a session is marked idle.
-
-=item KEEP_OLD_STATE_PERIOD => 1 * 60 * 60,  # 1h
-
-How long to keep idle session records on disk for fast reconnect with proper ip/mac/cookie match.
-
-=item USE_FPING => ON  # use fping to trigger idle clients
-
-Use fping(8) to trigger idle clients.
-
-=item FPING_OPTIONS => [qw(-c 1 -i 1 -t 1 -q)]   # SuSe default
-
-fping(8) options for current Linux distribution.
-
-=back
-
-=head2 LOCAL PARAMETERS, CHANGES NEEDED
-
-=over 4
-
-=item ADMIN_SECRET
-
-Passphrase for detailed sessions view.
-
-=item AUTHEN_SIMPLE_MODULES
-
-Authentication is handled by the Authen::Simple framework. You may stack any of the Authen::Simple::... plugins for authentication, see the $Bin/../etc/config.pl template.
-
-=item IPTABLES->capture_if => 'eth1'
-
-The inside gateway interface, e.g. 'eth1'. All http traffic, not allowed by any predefined rule, is captured and redirected to the capo.fcgi script.
-
-=item IPTABLES->capture_net => '192.168.0.0/22'
-
-The inside IP network in CIDR notation, e.g. '192.168.0.0/22'
-
-=item IPTABLES->capture_ports => [80, 8080]
-
-What tcp ports should be captured and redirected, e.g. [ 80, 8080]
-
-=item IPTABLES->redirect_port => 5281
-
-The port where the HTTP-server is listen in order to rewrite this http request to an https request.
-
-The above settings result in a NAT rule equivalent to:
-
- iptables -t nat -A PREROUTING -i eth1 -s 192.168.0.0/22 ! -d 192.168.0.0/22 \
-          -p tcp -m multiport --dports 80,8080 -j  REDIRECT --to-port 5281
-
-=item IPTABLES->throttle => OFF
-
-You may throttle HTTP/HTTPS requests/sec per client IP. Some clients/gadgets fire a lot of HTTP traffic without human intervention. Depending on your hardware and your encryption resources this will overload your gateway.
-
-=item IPTABLES->throttle_ports => [ 80, 5281]
-
-You should protect/throttle port 80 and the redirect_port (see above).
-
-
-=item IPTABLES->throttle_seconds => 30
-
-=item IPTABLES->throttle_hitcount => 15
-
-Both parameters define the average and the burst. Average is hitcount/seconds and burst is hitcount in seconds. With the values of 30 and 15, the average would be 15hits/30s => 1hit/2s. The burst would be 15hits in 30 seconds.
-
-The above settings result in iptable rules equivalent to:
-
- # throttle/drop new connections
- iptables -t filter -A INPUT -p tcp --syn -m multiport --dports 80,5281 \
-    -m recent --name capo_throttle --rcheck --seconds 30 --hitcount 15 -j DROP
-
- # at last accept new connections but set/update the recent table
- iptables -t filter -A INPUT -p tcp --syn -m multiport --dports 80,5281 \
-    -m recent --name capo_throttle --set -j ACCEPT
-
-=item IPTABLES->open_services
-
-Allow access to open local services like DHCP, DNS, NTP, ...
-
-=item IPTABLES->open_clients
-
-Allow access for some dumb clients without autentication.
-
-=item IPTABLES->open_servers
-
-Allow access to some open servers.
-
-=item IPTABLES->open_networks
-
-Allow access to some open networks.
-
-=item I18N_LANGUAGES
-
-Supported languages for system messages and HTML templates.
-
-=item I18N_FALLBACK_LANG
-
-Fallback language if the client message isn't supported in the system message catalog and templates.
-
-=item I18N_MSG_CATALOG
-
-Translations of the system messages.
-
-=back
-
 =head1 LOGGING
 
 Logging is handled by the Log::Log4perl module. The logging configuration is searched in the following default places:
@@ -246,6 +95,16 @@ Logging is handled by the Log::Log4perl module. The logging configuration is sea
     $Bin/../etc/local/log4perl.conf ||
     $Bin/../etc/log4perl.conf
 
+=head1 LOCAL ADAPTATION
+
+The HTML files are generated from templates (Template-Toolkit syntax). You should use the original template files as stanzas and put the locally changed versions into the local template tree. See template search order prefers the local templates.
+
+The firewall rules and commands are also generated from template files. Normally there should no need to change the firewall rules but it would be possible without changing the perl code.
+
+=head1 I18N
+
+There exists a template tree for each supported language. Some system/error messages used by the program must also be translated for the message catalog in the config file.
+
 =cut
 
 use POSIX qw(strftime);
@@ -1061,25 +920,7 @@ EOF_500
 
 =head1 SEE ALSO
 
-=over 4
-
-=item capo.fcgi
-
-(f)cgi script for Captive::Portal
-
-=item capo-ctl.pl
-
-Controller script for Captive::Portal
-
-=item test-server.pl
-
-Simple HTTP server based on HTTP::Server::Simple::CGI to test the Captive::Portal installation. Don't use it for production.
-
-=item mock-server.pl
-
-Simple HTTP server based on WWW::Mechanize::CGI for the test suite during installation.
-
-=back
+L<Captive::Portal::Role::Config>, L<capo.fcgi> and L<capo-ctl.pl>
 
 =head1 BUGS AND LIMITATIONS
 
